package tokenservicelogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-permission-server/pkg/domain/usecase"

	"code.30cm.net/digimon/app-cloudep-permission-server/gen_result/pb/permission"
	"code.30cm.net/digimon/app-cloudep-permission-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type CancelTokensLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewCancelTokensLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CancelTokensLogic {
	return &CancelTokensLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// CancelTokens 取消 Token 從UID 視角，以及 token id 視角出發， UID 登出，底下所有 Device ID 也要登出， Token ID 登出， 所有 UID + Device 都要登出
func (l *CancelTokensLogic) CancelTokens(in *permission.DoTokenByUIDReq) (*permission.OKResp, error) {
	req := usecase.RevokeTokensByUIDRequest{}
	if in.GetUid() != "" {
		req.UID = in.GetUid()
	}

	if len(in.GetIds()) > 0 {
		req.IDs = in.GetIds()
	}

	err := l.svcCtx.TokenUseCase.RevokeTokensByUID(l.ctx, req)
	if err != nil {
		return nil, err
	}

	return &permission.OKResp{}, nil
}
