package tokenservicelogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-permission-server/pkg/domain/token"

	"code.30cm.net/digimon/app-cloudep-permission-server/gen_result/pb/permission"
	"code.30cm.net/digimon/app-cloudep-permission-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUserTokensByDeviceIDLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetUserTokensByDeviceIDLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUserTokensByDeviceIDLogic {
	return &GetUserTokensByDeviceIDLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// GetUserTokensByDeviceID 取得目前所對應的 DeviceID 所存在的 Tokens
func (l *GetUserTokensByDeviceIDLogic) GetUserTokensByDeviceID(in *permission.DoTokenByDeviceIDReq) (*permission.Tokens, error) {
	id, err := l.svcCtx.TokenUseCase.GetUserTokensByDeviceID(l.ctx, in.GetDeviceId())
	if err != nil {
		return nil, err
	}
	tokenType := token.Bearer

	result := make([]*permission.TokenResp, 0, len(id))
	for _, v := range id {
		result = append(result, &permission.TokenResp{
			AccessToken:  v.AccessToken,
			ExpiresIn:    v.ExpiresIn,
			RefreshToken: v.RefreshToken,
			TokenType:    tokenType.ToString(),
		})
	}

	return &permission.Tokens{
		Token: result,
	}, nil
}
