package tokenservicelogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-permission-server/pkg/domain/token"

	"code.30cm.net/digimon/app-cloudep-permission-server/gen_result/pb/permission"
	"code.30cm.net/digimon/app-cloudep-permission-server/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUserTokensByUIDLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetUserTokensByUIDLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUserTokensByUIDLogic {
	return &GetUserTokensByUIDLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// GetUserTokensByUid 取得目前所對應的 UID 所存在的 Tokens
func (l *GetUserTokensByUIDLogic) GetUserTokensByUID(in *permission.QueryTokenByUIDReq) (*permission.Tokens, error) {
	uid, err := l.svcCtx.TokenUseCase.GetUserTokensByUID(l.ctx, in.GetUid())
	if err != nil {
		return nil, err
	}

	tokenType := token.Bearer

	result := make([]*permission.TokenResp, 0, len(uid))
	for _, v := range uid {
		result = append(result, &permission.TokenResp{
			AccessToken:  v.AccessToken,
			ExpiresIn:    v.ExpiresIn,
			RefreshToken: v.RefreshToken,
			TokenType:    tokenType.ToString(),
		})
	}

	return &permission.Tokens{
		Token: result,
	}, nil
}
